@@ -15,12 +15,10 @@ import numpy as np
 import pandas as pd
 
 import dash
-import dash_core_components as dcc
-import dash_bootstrap_components as dbc
-import dash_html_components as html
-
-from dash.dependencies import Input, Output, State
+from dash import html, dcc, Input, Output, State
 from dash.exceptions import PreventUpdate
+import dash_bootstrap_components as dbc
+
 import plotly.graph_objs as go
 
 from ..dashboard_methods import *
