@@ -5,13 +5,9 @@ __all__ = [
 ]
 
 import dash
-import dash_core_components as dcc
-import dash_bootstrap_components as dbc
-import dash_html_components as html
-import dash_table
-
-from dash.dependencies import Input, Output, State
+from dash import html, dcc, Input, Output, State, dash_table
 from dash.exceptions import PreventUpdate
+import dash_bootstrap_components as dbc
 
 from ..explainers import RandomForestExplainer, XGBExplainer
 from ..dashboard_methods import *
