@@ -8,12 +8,9 @@ __all__ = ['ShapSummaryComponent',
             'ShapContributionsGraphComponent']
 
 import dash
-import dash_core_components as dcc
-import dash_bootstrap_components as dbc
-import dash_html_components as html
-
-from dash.dependencies import Input, Output, State
+from dash import html, dcc, Input, Output, State
 from dash.exceptions import PreventUpdate
+import dash_bootstrap_components as dbc
 
 from ..dashboard_methods import *
 from .. import to_html
