@@ -1,5 +1,6 @@
 __all__ = [
     'IndexNotFoundError',
+    'append_dict_to_df',
     'safe_isinstance',
     'guess_shap',
     'mape_score',
@@ -50,6 +51,22 @@ from sklearn.model_selection import KFold, StratifiedKFold
 from joblib import Parallel, delayed
 
 
+def append_dict_to_df(df, row_dict):
+    """Appends a row to the dataframe 'df' and returns the new
+    dataframe.
+    
+    Args:
+        df (pd.DataFrame) data frame
+    
+        row_dict (dict): row data
+
+    Returns:
+        pd.DataFrame
+    """
+    return pd.concat([df, pd.DataFrame([row_dict])],
+                     ignore_index=True)
+
+
 class IndexNotFoundError(Exception):
     def __init__(self, message="Index not Found", index=None):
         if index is not None:
@@ -101,7 +118,8 @@ def guess_shap(model):
 
     skorch_models = ['skorch.net.NeuralNet',
                      'skorch.regressor.NeuralNetRegressor',
-                     'skorch.classifier.NeuralNetClassifier']
+                     'skorch.classifier.NeuralNetClassifier',
+                     'skorch.classifier.NeuralNetBinaryClassifier']
     
     for tree_model in tree_models:
         if str(type(model)).endswith(tree_model + "'>"):
@@ -190,7 +208,7 @@ def get_encoded_and_regular_cols(cols, onehot_dict):
     return encoded_cols, regular_cols
 
 
-def split_pipeline(pipeline, X, verbose=1):
+def split_pipeline(pipeline:Pipeline, X:pd.DataFrame, verbose:int=1):
     """Returns an X_transformed dataframe and model from a fitted 
     sklearn.pipelines.Pipeline and input dataframe X. Currently only supports
     Pipelines that do not change or reorder the columns in the input dataframe.
@@ -204,30 +222,33 @@ def split_pipeline(pipeline, X, verbose=1):
         X_transformed, model
     
     """
-    if verbose:
-        print("Warning: there is currently limited support for sklearn.Pipelines in explainerdashboard. "
-            "Only pipelines that return the same number of columns in the same order are supported, "
-            "until sklearn properly implements a pipeline.get_feature_names() method.", flush=True)
     assert hasattr(pipeline.steps[-1][1], 'predict'), \
         ("When passing an sklearn.Pipeline, the last step of the pipeline should be a model, "
          f"but {pipeline.steps[-1][1]} does not have a .predict() function!")
-    model = pipeline.steps[-1][1]
+    transformer_pipeline, model = pipeline[:-1], pipeline.steps[-1][1]
     
     if X is None:
         return X, model
     
-    X_transformed, columns = Pipeline(pipeline.steps[:-1]).transform(X), None
+    X_transformed, columns = transformer_pipeline.transform(X), None
     
-    if hasattr(pipeline, "get_feature_names"):
+    if hasattr(transformer_pipeline, "get_feature_names_out"):
         try:
-            columns = pipeline.get_feature_names()
-        except:
-            pass
-        else:
-            if len(columns) != X_transformed.shape[0]:
-                print(f"len(pipeline.get_feature_names())={len(columns)} does"
-                      f" not equal X_transformed.shape[0]={X_transformed.shape[0]}!", flush=True)
+            columns = list(transformer_pipeline.get_feature_names_out())
+        except Exception as e:
+            print("Failed to to get the output feature names from your Pipeline! "
+                  "Probably the .get_feature_names_out() method is not yet implemented "
+                  "for one of your pipeline components. "
+                  "Check https://github.com/scikit-learn/scikit-learn/issues/21308 for progress...")
+            if X_transformed.shape[1] != X.shape[1]:
+                raise ValueError(f"pipeline adds new features but failed to get feature names from"
+                                ".get_feature_names_out() method! \n\n{e}")
+            else:
                 columns = None
+        else:
+            if len(columns) != X_transformed.shape[1]:
+                raise ValueError(f"len(pipeline[:-1].get_feature_names_out())={len(columns)} does"
+                      f" not equal X_transformed.shape[1]={X_transformed.shape[1]}!")
     if columns is None and X_transformed.shape == X.values.shape:
         for i, pipe in enumerate(pipeline):
             if hasattr(pipe, "n_features_in_"):
@@ -239,9 +260,9 @@ def split_pipeline(pipeline, X, verbose=1):
               f"so assigning column names from X.columns: {X.columns.tolist()}, so"
               " make sure that your pipeline does not add, remove or reorders columns!", flush=True)
         columns = X.columns
-    else:
+    elif columns is None:
         raise ValueError("Pipeline does not return same number of columns as input, "
-                        "nor does it have a proper .get_feature_names() method! "
+                        "nor does it have a proper .get_feature_names_out() method! "
                         "Try passing the final estimator in the pipeline seperately "
                         "together with an already transformed dataframe.")
         
@@ -249,6 +270,65 @@ def split_pipeline(pipeline, X, verbose=1):
     return X_transformed, model
 
 
+# def split_pipeline(pipeline, X, verbose=1):
+#     """Returns an X_transformed dataframe and model from a fitted 
+#     sklearn.pipelines.Pipeline and input dataframe X. Currently only supports
+#     Pipelines that do not change or reorder the columns in the input dataframe.
+    
+#     Args:
+#         pipeline (sklearn.Pipeline): a fitted pipeline with an estimator 
+#             with .predict method as the last step.
+#         X (pd.DataFrame): input dataframe
+        
+#     Returns:
+#         X_transformed, model
+    
+#     """
+#     if verbose:
+#         print("Warning: there is currently limited support for sklearn.Pipelines in explainerdashboard. "
+#             "Only pipelines that return the same number of columns in the same order are supported, "
+#             "until sklearn properly implements a pipeline.get_feature_names() method.", flush=True)
+#     assert hasattr(pipeline.steps[-1][1], 'predict'), \
+#         ("When passing an sklearn.Pipeline, the last step of the pipeline should be a model, "
+#          f"but {pipeline.steps[-1][1]} does not have a .predict() function!")
+#     model = pipeline.steps[-1][1]
+    
+#     if X is None:
+#         return X, model
+    
+#     X_transformed, columns = Pipeline(pipeline.steps[:-1]).transform(X), None
+    
+#     if hasattr(pipeline, "get_feature_names"):
+#         try:
+#             columns = pipeline.get_feature_names()
+#         except:
+#             pass
+#         else:
+#             if len(columns) != X_transformed.shape[0]:
+#                 print(f"len(pipeline.get_feature_names())={len(columns)} does"
+#                       f" not equal X_transformed.shape[0]={X_transformed.shape[0]}!", flush=True)
+#                 columns = None
+#     if columns is None and X_transformed.shape == X.values.shape:
+#         for i, pipe in enumerate(pipeline):
+#             if hasattr(pipe, "n_features_in_"):
+#                 assert pipe.n_features_in_ == len(X.columns), \
+#                     (f".n_features_in_ did not match len(X.columns)={len(X.columns)} for pipeline step {i}: {pipe}!"
+#                      "For now explainerdashboard only supports sklearn Pipelines that have a "
+#                      ".get_feature_names() method or do not add/drop any columns...")
+#         print("Note: sklearn.Pipeline output shape is equal to X input shape, "
+#               f"so assigning column names from X.columns: {X.columns.tolist()}, so"
+#               " make sure that your pipeline does not add, remove or reorders columns!", flush=True)
+#         columns = X.columns
+#     else:
+#         raise ValueError("Pipeline does not return same number of columns as input, "
+#                         "nor does it have a proper .get_feature_names() method! "
+#                         "Try passing the final estimator in the pipeline seperately "
+#                         "together with an already transformed dataframe.")
+        
+#     X_transformed = pd.DataFrame(X_transformed, columns=columns)
+#     return X_transformed, model
+
+
 def retrieve_onehot_value(X, encoded_col, onehot_cols, not_encoded="NOT_ENCODED", sep="_"):
     """
     Reverses a onehot encoding. 
@@ -1094,8 +1174,8 @@ def get_contrib_summary_df(contrib_df, model_output="raw", round=2, units="", na
         else:
             effect +=  str(np.round(row['contribution'], round)) + f" {units}"
 
-        contrib_summary_df = contrib_summary_df.append(
-            dict(Reason=reason, Effect=effect), ignore_index=True)
+        contrib_summary_df = append_dict_to_df(contrib_summary_df,
+            dict(Reason=reason, Effect=effect))
     
     return contrib_summary_df.reset_index(drop=True)
 
@@ -1162,7 +1242,7 @@ def get_decisionpath_df(decision_tree, observation, pos_label=1):
             return node.class_counts()[pos_label]/ sum(node.class_counts())
         for node in nodes:
             if not node.isleaf():
-                decisiontree_df = decisiontree_df.append({
+                decisiontree_df = append_dict_to_df(decisiontree_df, {
                     'node_id' : node.id,
                     'average' : node_pred_proba(node),
                     'feature' : node.feature_name(),
@@ -1174,14 +1254,14 @@ def get_decisionpath_df(decision_tree, observation, pos_label=1):
                     'diff' : node_pred_proba(node.left) - node_pred_proba(node) \
                                 if observation[node.feature_name()] < node.split() \
                                 else node_pred_proba(node.right) - node_pred_proba(node)
-                }, ignore_index=True)
+                })
 
     else:
         def node_mean(node):
             return decision_tree.tree_model.tree_.value[node.id].item()
         for node in nodes:
             if not node.isleaf():
-                decisiontree_df = decisiontree_df.append({
+                decisiontree_df = append_dict_to_df(decisiontree_df, {
                     'node_id' : node.id,
                     'average' : node_mean(node),
                     'feature' : node.feature_name(),
@@ -1193,7 +1273,7 @@ def get_decisionpath_df(decision_tree, observation, pos_label=1):
                     'diff' : node_mean(node.left) - node_mean(node) \
                                 if observation[node.feature_name()] < node.split() \
                                 else node_mean(node.right) - node_mean(node)
-                }, ignore_index=True)
+                })
     return decisiontree_df
 
 
@@ -1221,35 +1301,35 @@ def get_decisiontree_summary_df(decisiontree_df, classifier=False, round=2, unit
 
 
     decisiontree_summary_df = pd.DataFrame(columns=['Feature', 'Condition', 'Adjustment', 'New Prediction'])
-    decisiontree_summary_df = decisiontree_summary_df.append({
+    decisiontree_summary_df = append_dict_to_df(decisiontree_summary_df, {
                             'Feature' : "",
                             'Condition' : "",
                             'Adjustment' : "Starting average",
                             'New Prediction' : str(np.round(base_value, round)) + ('%' if classifier else f' {units}')
-                        }, ignore_index=True)
+                        })
 
     for _, row in decisiontree_df.iterrows():
         if classifier:
-            decisiontree_summary_df = decisiontree_summary_df.append({
+            decisiontree_summary_df = append_dict_to_df(decisiontree_summary_df, {
                             'Feature' : row['feature'],
                             'Condition' : str(row['value']) + str(' >= ' if row['direction'] == 'right' else ' < ') + str(row['split']).ljust(10),
                             'Adjustment' : str('+' if row['diff'] >= 0 else '') + str(np.round(100*row['diff'], round)) +'%',
                             'New Prediction' : str(np.round(100*(row['average']+row['diff']), round)) + '%'
-                        }, ignore_index=True)
+                        })
         else:
-            decisiontree_summary_df = decisiontree_summary_df.append({
+            decisiontree_summary_df = append_dict_to_df(decisiontree_summary_df, {
                             'Feature' : row['feature'],
                             'Condition' : str(row['value']) + str(' >= ' if row['direction'] == 'right' else ' < ') + str(row['split']).ljust(10),
                             'Adjustment' : str('+' if row['diff'] >= 0 else '') + str(np.round(row['diff'], round)),
                             'New Prediction' : str(np.round((row['average']+row['diff']), round)) + f" {units}"
-                        }, ignore_index=True)
+                        })
 
-    decisiontree_summary_df = decisiontree_summary_df.append({
+    decisiontree_summary_df = append_dict_to_df( decisiontree_summary_df, {
                         'Feature' : "",
                         'Condition' : "",
                         'Adjustment' : "Final Prediction",
                         'New Prediction' : str(np.round(prediction, round)) + ('%' if classifier else '') + f" {units}"
-                    }, ignore_index=True)
+                    })
 
     return decisiontree_summary_df
 
@@ -1316,20 +1396,20 @@ def get_xgboost_path_df(xgbmodel, X_row, n_tree=None):
     
     node = node_dict[0]
     while not node['is_leaf']:
-        prediction_path_df = prediction_path_df.append(
+        prediction_path_df = append_dict_to_df(prediction_path_df,
             dict(
                 node=node['node'], 
                 feature=node['feature'], 
                 cutoff=node['cutoff'], 
                 value=float(X_row[node['feature']])
-            ), ignore_index=True)
+            ))
         if np.isnan(X_row[node['feature']]) or X_row[node['feature']] < node['cutoff']:
             node = node_dict[node['left_node']]
         else:
             node = node_dict[node['right_node']]
     
     if node['is_leaf']:
-        prediction_path_df = prediction_path_df.append(dict(node=node['node'], feature="_PREDICTION", value=node['leaf_value']), ignore_index=True)
+        prediction_path_df = append_dict_to_df(prediction_path_df, dict(node=node['node'], feature="_PREDICTION", value=node['leaf_value']))
     return prediction_path_df
 
 
@@ -1348,25 +1428,25 @@ def get_xgboost_path_summary_df(xgboost_path_df, output="margin"):
 
     for row in xgboost_path_df.itertuples():
         if row.feature == "_PREDICTION":
-            xgboost_path_summary_df = xgboost_path_summary_df.append(
+            xgboost_path_summary_df = append_dict_to_df(xgboost_path_summary_df,
                 dict(
                     node=row.node, 
                     split_condition=f"prediction ({output}) = {row.value}" 
-                ), ignore_index=True
-            )   
+                )
+            )
         elif row.value < row.cutoff:
-            xgboost_path_summary_df = xgboost_path_summary_df.append(
+            xgboost_path_summary_df = append_dict_to_df(xgboost_path_summary_df,
                 dict(
                     node=row.node, 
                     split_condition=f"{row.feature} = {row.value} < {row.cutoff}"
-                ), ignore_index=True
+                )
             )
         else:
-            xgboost_path_summary_df = xgboost_path_summary_df.append(
+            xgboost_path_summary_df = append_dict_to_df(xgboost_path_summary_df,
                 dict(
                     node=row.node, 
                     split_condition=f"{row.feature} = {row.value} >= {row.cutoff}"
-                ), ignore_index=True
+                )
             )
     return xgboost_path_summary_df
 
